@@ -55,10 +55,14 @@ from roborock.roborock_message import (
 )
 from roborock.util import RepeatableTask, get_next_int, unpack_list
 
-COMMANDS_SECURED = [
+COMMANDS_SECURED = {
     RoborockCommand.GET_MAP_V1,
     RoborockCommand.GET_MULTI_MAP,
-]
+}
+
+CUSTOM_COMMANDS = {RoborockCommand.GET_MAP_CALIBRATION}
+
+CLOUD_REQUIRED = COMMANDS_SECURED.union(CUSTOM_COMMANDS)
 
 WASH_N_FILL_DOCK = [
     RoborockDockTypeCode.empty_wash_fill_dock,
@@ -357,7 +361,7 @@ class RoborockClientV1(RoborockClient):
 
     def on_message_received(self, messages: list[RoborockMessage]) -> None:
         try:
-            self._last_device_msg_in = self.time_func()
+            self._last_device_msg_in = time.monotonic()
             for data in messages:
                 protocol = data.protocol
                 if data.payload and protocol in [
@@ -387,6 +391,8 @@ class RoborockClientV1(RoborockClient):
                                     if isinstance(result, list) and len(result) == 1:
                                         result = result[0]
                                     queue.resolve((result, None))
+                            else:
+                                self._logger.debug("Received response for unknown request id %s", request_id)
                         else:
                             try:
                                 data_protocol = RoborockDataProtocol(int(data_point_number))
@@ -439,10 +445,14 @@ class RoborockClientV1(RoborockClient):
                             if isinstance(decompressed, list):
                                 decompressed = decompressed[0]
                             queue.resolve((decompressed, None))
+                        else:
+                            self._logger.debug("Received response for unknown request id %s", request_id)
                 else:
                     queue = self._waiting_queue.get(data.seq)
                     if queue:
                         queue.resolve((data.payload, None))
+                    else:
+                        self._logger.debug("Received response for unknown request id %s", data.seq)
         except Exception as ex:
             self._logger.exception(ex)
 
